define({ root:

//begin v1.x content
{
	"field-thu-narrow-relative+0": "this Thursday",
	"field-thu-narrow-relative+1": "next Thursday",
	"field-sun-narrow-relative+0": "this Sunday",
	"field-sun-narrow-relative+1": "next Sunday",
	"field-wed-narrow@localeAlias1815": {
		"bundle": "",
		"target": "field-wed-short"
	},
	"months-format-wide": [
		"M01",
		"M02",
		"M03",
		"M04",
		"M05",
		"M06",
		"M07",
		"M08",
		"M09",
		"M10",
		"M11",
		"M12"
	],
	"field-wed-narrow@localeAlias1816": {
		"bundle": "",
		"target": "field-wed"
	},
	"dayPeriods-standAlone-abbr-pm": "PM",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-fri-narrow-relative+0": "this Friday",
	"eraNarrow": [
		"Before R.O.C.",
		"R.O.C."
	],
	"field-fri-narrow-relative+1": "next Friday",
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"days-standAlone-wide": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"dateFormatItem-Ehm": "E h:mm a",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-wed-narrow-relative+-1": "last Wednesday",
	"field-minute-narrow-relative+0": "this minute",
	"days-format-wide": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-month-short-relative+0": "this month",
	"field-month-short-relative+1": "next month",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"field-quarter-narrow@localeAlias1782": {
		"bundle": "",
		"target": "field-quarter-short"
	},
	"field-thu-relative+0": "this Thursday",
	"field-quarter-narrow@localeAlias1783": {
		"bundle": "",
		"target": "field-quarter"
	},
	"dayPeriods-format-wide-am": "AM",
	"field-thu-relative+1": "next Thursday",
	"months@localeAlias1739": {
		"bundle": "gregorian",
		"target": "months"
	},
	"field-fri-relative+0": "this Friday",
	"field-fri-relative+1": "next Friday",
	"field-quarter-relative+0": "this quarter",
	"field-thu-narrow-relative+-1": "last Thursday",
	"field-quarter-relative+1": "next quarter",
	"field-month-narrow@localeAlias1785": {
		"bundle": "",
		"target": "field-month-short"
	},
	"field-sun-short-relative+0": "this Sunday",
	"timeFormat-short": "HH:mm",
	"field-month-narrow@localeAlias1786": {
		"bundle": "",
		"target": "field-month"
	},
	"field-sun-short-relative+1": "next Sunday",
	"field-year-narrow@localeAlias1779": {
		"bundle": "",
		"target": "field-year-short"
	},
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-Md": "MM-dd",
	"field-week-narrow": "Week",
	"eraNames@localeAlias1770": {
		"bundle": "roc",
		"target": "eraAbbr"
	},
	"days-format-short@localeAlias1748": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"field-hour-relative+0": "this hour",
	"days-format-short@localeAlias1749": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"field-day-relative+-1": "yesterday",
	"field-mon-narrow-relative+-1": "last Monday",
	"field-minute-narrow": "Minute",
	"field-dayOfYear-short@localeAlias1796": {
		"bundle": "",
		"target": "field-dayOfYear"
	},
	"field-year-narrow@localeAlias1780": {
		"bundle": "",
		"target": "field-year"
	},
	"dateFormatItem-yyyyMMM": "G y MMM",
	"field-thu-short-relative+0": "this Thursday",
	"field-mon-relative+0": "this Monday",
	"field-thu-short-relative+1": "next Thursday",
	"field-mon-relative+1": "next Monday",
	"dateTimeFormats-appendItem-Era": "{1} {0}",
	"field-day-narrow-relative+0": "today",
	"field-era-short": "Era",
	"field-day-narrow-relative+1": "tomorrow",
	"field-sat-narrow-relative+0": "this Saturday",
	"timeFormat-long": "HH:mm:ss z",
	"field-sat-narrow-relative+1": "next Saturday",
	"field-week-narrow-relative+0": "this week",
	"field-week-narrow-relative+1": "next week",
	"field-hour-short-relative+0": "this hour",
	"field-wed-narrow-relative+0": "this Wednesday",
	"field-wed-narrow-relative+1": "next Wednesday",
	"field-wed-short@localeAlias1814": {
		"bundle": "",
		"target": "field-wed"
	},
	"field-month": "Month",
	"months-standAlone-wide": [
		"M01",
		"M02",
		"M03",
		"M04",
		"M05",
		"M06",
		"M07",
		"M08",
		"M09",
		"M10",
		"M11",
		"M12"
	],
	"field-thu-short@localeAlias1817": {
		"bundle": "",
		"target": "field-thu"
	},
	"dateTimeFormats-appendItem-Second": "{0} ({2}: {1})",
	"field-weekday-narrow": "Day of the Week",
	"field-year-relative+0": "this year",
	"field-year-relative+1": "next year",
	"field-tue-relative+0": "this Tuesday",
	"field-tue-relative+1": "next Tuesday",
	"field-minute-short-relative+0": "this minute",
	"dateFormatItem-hm": "h:mm a",
	"field-year-narrow": "Year",
	"months-format-narrow@localeAlias1741": {
		"bundle": "gregorian",
		"target": "months-standAlone-narrow"
	},
	"dateTimeFormats-appendItem-Day": "{0} ({2}: {1})",
	"field-tue-short-relative+0": "this Tuesday",
	"field-weekday-short@localeAlias1799": {
		"bundle": "",
		"target": "field-weekday"
	},
	"field-tue-short-relative+1": "next Tuesday",
	"dateTimeFormats-appendItem-Year": "{1} {0}",
	"dateTimeFormats-appendItem-Day-Of-Week": "{0} {1}",
	"field-tue-narrow-relative+0": "this Tuesday",
	"field-tue-narrow-relative+1": "next Tuesday",
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-E": "ccc",
	"days-standAlone-abbr@localeAlias1750": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"dateFormatItem-EBhm": "E h:mm B",
	"days-standAlone-abbr@localeAlias1751": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"dateFormatItem-H": "HH",
	"field-era-short@localeAlias1775": {
		"bundle": "",
		"target": "field-era"
	},
	"field-wed-relative+0": "this Wednesday",
	"field-wed-relative+1": "next Wednesday",
	"dateFormatItem-M": "L",
	"field-wed-short-relative+0": "this Wednesday",
	"field-wed-short-relative+1": "next Wednesday",
	"field-fri-short-relative+0": "this Friday",
	"field-weekOfMonth-short": "Week Of Month",
	"field-quarter-short@localeAlias1781": {
		"bundle": "",
		"target": "field-quarter"
	},
	"field-fri-short-relative+1": "next Friday",
	"field-quarter-short-relative+-1": "last quarter",
	"field-year-short-relative+-1": "last year",
	"dateFormatItem-Bhm": "h:mm B",
	"dateTimeFormats-appendItem-Hour": "{0} ({2}: {1})",
	"dateTimeFormat-medium": "{1} {0}",
	"field-quarter-narrow-relative+-1": "last quarter",
	"dateFormatItem-d": "d",
	"dayPeriods-format-abbr-pm": "PM",
	"months-format-abbr@localeAlias1740": {
		"bundle": "gregorian",
		"target": "months-format-wide"
	},
	"dateFormatItem-h": "h a",
	"quarters-standAlone-wide": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-weekOfMonth-narrow": "Week Of Month",
	"dateFormatItem-yyyyQQQ": "G y QQQ",
	"dateFormatItem-yyyyMMMM": "G y MMMM",
	"dateFormatItem-y": "G y",
	"field-weekdayOfMonth-narrow@localeAlias1803": {
		"bundle": "",
		"target": "field-weekdayOfMonth-short"
	},
	"field-minute-relative+0": "this minute",
	"field-year-short-relative+0": "this year",
	"field-weekdayOfMonth-narrow@localeAlias1804": {
		"bundle": "",
		"target": "field-weekdayOfMonth"
	},
	"dateFormatItem-EBhms": "E h:mm:ss B",
	"field-year-short-relative+1": "next year",
	"field-weekday": "Day of the Week",
	"dayPeriods-format-narrow-pm": "PM",
	"dateTimeFormats-appendItem-Quarter": "{0} ({2}: {1})",
	"field-tue-narrow-relative+-1": "last Tuesday",
	"months-standAlone-abbr@localeAlias1742": {
		"bundle": "gregorian",
		"target": "months-format-abbr"
	},
	"months-standAlone-abbr@localeAlias1743": {
		"bundle": "gregorian",
		"target": "months-format-wide"
	},
	"field-minute-short@localeAlias1832": {
		"bundle": "",
		"target": "field-minute"
	},
	"field-year-narrow-relative+-1": "last year",
	"dateFormatItem-yyyyMMMd": "G y MMM d",
	"field-weekOfMonth-short@localeAlias1790": {
		"bundle": "",
		"target": "field-weekOfMonth"
	},
	"field-sat-relative+-1": "last Saturday",
	"field-mon-narrow@localeAlias1809": {
		"bundle": "",
		"target": "field-mon-short"
	},
	"field-sun-narrow@localeAlias1806": {
		"bundle": "",
		"target": "field-sun-short"
	},
	"field-sun-narrow@localeAlias1807": {
		"bundle": "",
		"target": "field-sun"
	},
	"dayPeriods-standAlone-narrow-pm": "PM",
	"field-mon-narrow-relative+0": "this Monday",
	"field-mon-narrow-relative+1": "next Monday",
	"field-second": "Second",
	"field-year-relative+-1": "last year",
	"field-mon-narrow@localeAlias1810": {
		"bundle": "",
		"target": "field-mon"
	},
	"field-weekdayOfMonth-short": "Weekday Of Month",
	"dateFormat-short": "GGGGG y-MM-dd",
	"field-second-narrow@localeAlias1836": {
		"bundle": "",
		"target": "field-second-short"
	},
	"eraNames": [
		"Before R.O.C.",
		"R.O.C."
	],
	"field-second-short": "Second",
	"field-second-narrow@localeAlias1837": {
		"bundle": "",
		"target": "field-second"
	},
	"field-thu-short-relative+-1": "last Thursday",
	"field-zone": "Zone",
	"field-dayperiod-narrow": "Dayperiod",
	"field-sun-short-relative+-1": "last Sunday",
	"eraAbbr": [
		"Before R.O.C.",
		"R.O.C."
	],
	"field-week-short": "Week",
	"dayPeriods-standAlone-abbr-am": "AM",
	"dayPeriods-standAlone-wide-pm": "PM",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+0": "today",
	"days-standAlone-short@localeAlias1752": {
		"bundle": "gregorian",
		"target": "days-format-short"
	},
	"field-day-relative+1": "tomorrow",
	"days-standAlone-short@localeAlias1753": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"days-standAlone-short@localeAlias1754": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"field-tue-short@localeAlias1811": {
		"bundle": "",
		"target": "field-tue"
	},
	"field-day-short-relative+0": "today",
	"field-dayOfYear-short": "Day Of Year",
	"field-day-short-relative+1": "tomorrow",
	"dateFormat-long": "G y MMMM d",
	"field-sun-narrow-relative+-1": "last Sunday",
	"field-zone-short@localeAlias1838": {
		"bundle": "",
		"target": "field-zone"
	},
	"field-week-narrow@localeAlias1788": {
		"bundle": "",
		"target": "field-week-short"
	},
	"field-week-narrow@localeAlias1789": {
		"bundle": "",
		"target": "field-week"
	},
	"days-format-narrow@localeAlias1747": {
		"bundle": "gregorian",
		"target": "days-standAlone-narrow"
	},
	"field-second-short@localeAlias1835": {
		"bundle": "",
		"target": "field-second"
	},
	"dateTime@localeAlias1774": {
		"bundle": "generic",
		"target": "dateTime"
	},
	"field-second-relative+0": "now",
	"field-weekdayOfMonth-short@localeAlias1802": {
		"bundle": "",
		"target": "field-weekdayOfMonth"
	},
	"field-quarter-relative+-1": "last quarter",
	"field-minute-narrow@localeAlias1833": {
		"bundle": "",
		"target": "field-minute-short"
	},
	"field-minute-narrow@localeAlias1834": {
		"bundle": "",
		"target": "field-minute"
	},
	"quarters-format-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"timeFormat@localeAlias1773": {
		"bundle": "gregorian",
		"target": "timeFormat"
	},
	"dayPeriods-standAlone-wide@localeAlias1768": {
		"bundle": "gregorian",
		"target": "dayPeriods-standAlone-abbr"
	},
	"dayPeriods-standAlone-wide@localeAlias1769": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-week-relative+-1": "last week",
	"field-month-relative+-1": "last month",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-dayOfYear-narrow@localeAlias1797": {
		"bundle": "",
		"target": "field-dayOfYear-short"
	},
	"field-dayOfYear-narrow@localeAlias1798": {
		"bundle": "",
		"target": "field-dayOfYear"
	},
	"field-year": "Year",
	"field-era": "Era",
	"days-standAlone-short": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-short-relative+-1": "yesterday",
	"dateFormatItem-GyMMM": "G y MMM",
	"timeFormat-full": "HH:mm:ss zzzz",
	"dateFormatItem-Bhms": "h:mm:ss B",
	"dayPeriods@localeAlias1762": {
		"bundle": "gregorian",
		"target": "dayPeriods"
	},
	"field-hour": "Hour",
	"quarters-standAlone-wide@localeAlias1761": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"field-weekOfMonth-narrow@localeAlias1791": {
		"bundle": "",
		"target": "field-weekOfMonth-short"
	},
	"field-weekOfMonth-narrow@localeAlias1792": {
		"bundle": "",
		"target": "field-weekOfMonth"
	},
	"field-sat-short@localeAlias1823": {
		"bundle": "",
		"target": "field-sat"
	},
	"quarters-format-abbr@localeAlias1757": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"field-dayOfYear-narrow": "Day Of Year",
	"field-second-narrow-relative+0": "now",
	"field-quarter": "Quarter",
	"field-month-narrow-relative+0": "this month",
	"field-month-narrow-relative+1": "next month",
	"field-tue-narrow@localeAlias1812": {
		"bundle": "",
		"target": "field-tue-short"
	},
	"field-tue-narrow@localeAlias1813": {
		"bundle": "",
		"target": "field-tue"
	},
	"dateFormatItem-yyyy": "G y",
	"dayPeriods-standAlone-narrow@localeAlias1766": {
		"bundle": "gregorian",
		"target": "dayPeriods-standAlone-abbr"
	},
	"dayPeriods-standAlone-narrow@localeAlias1767": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"dateTimeFormats-appendItem-Minute": "{0} ({2}: {1})",
	"field-day": "Day",
	"field-mon-relative+-1": "last Monday",
	"field-dayOfYear": "Day Of Year",
	"dateFormat-medium": "G y MMM d",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-GyMMMd": "G y MMM d",
	"dateFormatItem-MEd": "MM-dd, E",
	"field-tue-short-relative+-1": "last Tuesday",
	"field-year-short": "Year",
	"field-month-short": "Month",
	"field-day-short@localeAlias1793": {
		"bundle": "",
		"target": "field-day"
	},
	"dateFormatItem-MMMEd": "MMM d, E",
	"dateFormatItem-MMMd": "MMM d",
	"dateFormatItem-Bh": "h B",
	"months-format-abbr": [
		"M01",
		"M02",
		"M03",
		"M04",
		"M05",
		"M06",
		"M07",
		"M08",
		"M09",
		"M10",
		"M11",
		"M12"
	],
	"field-mon-short@localeAlias1808": {
		"bundle": "",
		"target": "field-mon"
	},
	"dayPeriods-format-abbr-am": "AM",
	"field-era-narrow@localeAlias1776": {
		"bundle": "",
		"target": "field-era-short"
	},
	"field-era-narrow@localeAlias1777": {
		"bundle": "",
		"target": "field-era"
	},
	"field-sat-relative+0": "this Saturday",
	"dayPeriods-format-wide-pm": "PM",
	"field-sat-relative+1": "next Saturday",
	"days-format-abbr@localeAlias1746": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"days-standAlone-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-zone-short": "Zone",
	"field-week-short-relative+0": "this week",
	"field-week-short-relative+1": "next week",
	"field-sun-short@localeAlias1805": {
		"bundle": "",
		"target": "field-sun"
	},
	"dateFormatItem-yyyyMMMEd": "G y MMM d, E",
	"dateTimeFormats-appendItem-Week": "{0} ({2}: {1})",
	"field-fri-short-relative+-1": "last Friday",
	"field-month-narrow": "Month",
	"dayPeriods-format-narrow-am": "AM",
	"field-month-narrow-relative+-1": "last month",
	"days-format-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"quarters-format-narrow@localeAlias1758": {
		"bundle": "gregorian",
		"target": "quarters-standAlone-narrow"
	},
	"field-weekday-short": "Day of the Week",
	"field-day-narrow-relative+-1": "yesterday",
	"field-fri-narrow@localeAlias1821": {
		"bundle": "",
		"target": "field-fri-short"
	},
	"field-fri-narrow@localeAlias1822": {
		"bundle": "",
		"target": "field-fri"
	},
	"field-quarter-short": "Quarter",
	"days-format-short": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"dateFormatItem-EHm": "E HH:mm",
	"dayPeriods-format-wide@localeAlias1764": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-quarter-narrow": "Quarter",
	"field-mon-short-relative+0": "this Monday",
	"field-mon-short-relative+1": "next Monday",
	"field-dayperiod-short": "Dayperiod",
	"dayPeriods-standAlone-narrow-am": "AM",
	"field-week-narrow-relative+-1": "last week",
	"field-thu-relative+-1": "last Thursday",
	"field-mon-short-relative+-1": "last Monday",
	"field-fri-narrow-relative+-1": "last Friday",
	"timeFormat-medium": "HH:mm:ss",
	"field-quarter-short-relative+0": "this quarter",
	"field-quarter-short-relative+1": "next quarter",
	"dateFormatItem-Ed": "d, E",
	"field-wed-relative+-1": "last Wednesday",
	"field-weekOfMonth": "Week Of Month",
	"field-weekdayOfMonth-narrow": "Weekday Of Month",
	"field-hour-narrow@localeAlias1830": {
		"bundle": "",
		"target": "field-hour-short"
	},
	"field-hour-narrow@localeAlias1831": {
		"bundle": "",
		"target": "field-hour"
	},
	"dayPeriods-standAlone-wide-am": "AM",
	"field-fri-relative+-1": "last Friday",
	"field-weekday-narrow@localeAlias1800": {
		"bundle": "",
		"target": "field-weekday-short"
	},
	"field-weekday-narrow@localeAlias1801": {
		"bundle": "",
		"target": "field-weekday"
	},
	"field-minute": "Minute",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-narrow@localeAlias1794": {
		"bundle": "",
		"target": "field-day-short"
	},
	"field-day-narrow@localeAlias1795": {
		"bundle": "",
		"target": "field-day"
	},
	"field-second-short-relative+0": "now",
	"quarters-format-wide": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-day-short": "Day",
	"field-dayperiod": "Dayperiod",
	"field-hour-short": "Hour",
	"months-standAlone-abbr": [
		"M01",
		"M02",
		"M03",
		"M04",
		"M05",
		"M06",
		"M07",
		"M08",
		"M09",
		"M10",
		"M11",
		"M12"
	],
	"field-month-relative+0": "this month",
	"field-second-narrow": "Second",
	"field-month-relative+1": "next month",
	"dateFormat-full": "G y MMMM d, EEEE",
	"dateFormatItem-yyyyMEd": "GGGGG y-MM-dd, E",
	"field-era-narrow": "Era",
	"field-sat-short-relative+-1": "last Saturday",
	"dayPeriods-standAlone-abbr@localeAlias1765": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"eraNarrow@localeAlias1771": {
		"bundle": "roc",
		"target": "eraAbbr"
	},
	"field-hour-short@localeAlias1829": {
		"bundle": "",
		"target": "field-hour"
	},
	"field-week-short-relative+-1": "last week",
	"dateTimeFormat-long": "{1} {0}",
	"field-sun-relative+-1": "last Sunday",
	"field-wed-short-relative+-1": "last Wednesday",
	"dateFormatItem-yyyyQQQQ": "G y QQQQ",
	"field-weekdayOfMonth": "Weekday Of Month",
	"dateFormatItem-yyyyMd": "GGGGG y-MM-dd",
	"field-zone-narrow@localeAlias1839": {
		"bundle": "",
		"target": "field-zone-short"
	},
	"field-quarter-narrow-relative+0": "this quarter",
	"dateFormatItem-GyMMMEd": "G y MMM d, E",
	"field-quarter-narrow-relative+1": "next quarter",
	"field-sat-short-relative+0": "this Saturday",
	"field-sat-short-relative+1": "next Saturday",
	"field-hour-narrow": "Hour",
	"quarters-standAlone-abbr@localeAlias1759": {
		"bundle": "gregorian",
		"target": "quarters-format-abbr"
	},
	"field-year-narrow-relative+0": "this year",
	"field-year-narrow-relative+1": "next year",
	"field-dayperiod-short@localeAlias1826": {
		"bundle": "",
		"target": "field-dayperiod"
	},
	"dateFormatItem-Gy": "G y",
	"field-zone-narrow": "Zone",
	"dateFormatItem-yyyyM": "GGGGG y-MM",
	"field-tue-relative+-1": "last Tuesday",
	"field-zone-narrow@localeAlias1840": {
		"bundle": "",
		"target": "field-zone"
	},
	"field-minute-short": "Minute",
	"days-standAlone-wide@localeAlias1755": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"quarters-standAlone-abbr@localeAlias1760": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"dateFormatItem-Hm": "HH:mm",
	"field-thu-narrow@localeAlias1818": {
		"bundle": "",
		"target": "field-thu-short"
	},
	"field-thu-narrow@localeAlias1819": {
		"bundle": "",
		"target": "field-thu"
	},
	"field-week-relative+0": "this week",
	"field-week-relative+1": "next week",
	"dateFormatItem-MMM": "LLL",
	"field-sun-relative+0": "this Sunday",
	"field-sun-relative+1": "next Sunday",
	"dateFormat@localeAlias1772": {
		"bundle": "generic",
		"target": "dateFormat"
	},
	"field-year-short@localeAlias1778": {
		"bundle": "",
		"target": "field-year"
	},
	"field-sat-narrow@localeAlias1824": {
		"bundle": "",
		"target": "field-sat-short"
	},
	"field-sat-narrow@localeAlias1825": {
		"bundle": "",
		"target": "field-sat"
	},
	"field-week-short@localeAlias1787": {
		"bundle": "",
		"target": "field-week"
	},
	"field-sat-narrow-relative+-1": "last Saturday",
	"dateTimeFormats-appendItem-Month": "{0} ({2}: {1})",
	"quarters-standAlone-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"dayPeriods-format-narrow@localeAlias1763": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-month-short@localeAlias1784": {
		"bundle": "",
		"target": "field-month"
	},
	"field-month-short-relative+-1": "last month",
	"field-fri-short@localeAlias1820": {
		"bundle": "",
		"target": "field-fri"
	},
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-MMMMd": "MMMM d",
	"field-week": "Week",
	"field-day-narrow": "Day",
	"field-hour-narrow-relative+0": "this hour",
	"field-dayperiod-narrow@localeAlias1827": {
		"bundle": "",
		"target": "field-dayperiod-short"
	},
	"months-standAlone-wide@localeAlias1744": {
		"bundle": "gregorian",
		"target": "months-format-wide"
	},
	"field-dayperiod-narrow@localeAlias1828": {
		"bundle": "",
		"target": "field-dayperiod"
	},
	"days@localeAlias1745": {
		"bundle": "gregorian",
		"target": "days"
	},
	"quarters@localeAlias1756": {
		"bundle": "gregorian",
		"target": "quarters"
	}
}
//end v1.x content
,
	"ar": true,
	"bs": true,
	"ca": true,
	"cs": true,
	"da": true,
	"de": true,
	"el": true,
	"en": true,
	"es": true,
	"fi": true,
	"fr": true,
	"he": true,
	"hr": true,
	"hu": true,
	"id": true,
	"it": true,
	"ja": true,
	"ko": true,
	"mk": true,
	"nb": true,
	"nl": true,
	"pl": true,
	"pt": true,
	"pt-pt": true,
	"ro": true,
	"ru": true,
	"sk": true,
	"sl": true,
	"sr": true,
	"sv": true,
	"th": true,
	"tr": true,
	"zh": true,
	"zh-hant": true
});